@@ -6,9 +6,9 @@ our ($ROUND, $PREC);
 Class::Multimethods::multimethod __atanh__ => qw(Math::MPFR) => sub {
     my ($x) = @_;
 
-    # Return a complex number for x <= -1 or x >= 1
-    if (   Math::MPFR::Rmpfr_cmp_ui($x, 1) >= 0
-        or Math::MPFR::Rmpfr_cmp_si($x, -1) <= 0) {
+    # Return a complex number for x < -1 or x > 1
+    if (   Math::MPFR::Rmpfr_cmp_ui($x, +1) > 0
+        or Math::MPFR::Rmpfr_cmp_si($x, -1) < 0) {
         my $r = _mpfr2mpc($x);
         Math::MPC::Rmpc_atanh($r, $r, $ROUND);
         return $r;
