@@ -22,53 +22,35 @@ Class::Multimethods::multimethod __stringify__ => qw(Math::MPFR) => sub {
                 );
 
     # log(10)/log(2) =~ 3.3219280948873623
-    my $digits = CORE::int($PREC >> 2);
-    my $str = Math::MPFR::Rmpfr_get_str($x, 10, $digits, $ROUND);
+    my $digits = $PREC >> 2;
+    my ($mantissa, $exponent) = Math::MPFR::Rmpfr_deref2($x, 10, $digits, $ROUND);
 
-    if ($str =~ s/e(-?[0-9]+)\z//) {
-        my $exp = $1;
+    my $sgn = '';
+    if (substr($mantissa, 0, 1) eq '-') {
+        $sgn = substr($mantissa, 0, 1, '');
+    }
 
-        my $sgn = '';
-        if (substr($str, 0, 1) eq '-') {
-            $sgn = '-';
-            substr($str, 0, 1, '');
-        }
+    $mantissa =~ /[^0]/ or return '0';
 
-        my ($before, $after) = split(/\./, $str);
+    if (CORE::abs($exponent) < CORE::length($mantissa)) {
 
-        if ($exp > 0) {
-            if ($exp >= CORE::length($after)) {
-                $after = '.' . $after . "e$exp";
-            }
-            else {
-                substr($after, $exp, 0, '.');
-            }
+        if ($exponent > 0) {
+            substr($mantissa, $exponent, 0, '.');
         }
         else {
-            if (CORE::abs($exp) >= CORE::length($before)) {
-
-                my $diff = CORE::abs($exp) - CORE::length($before);
-
-                if ($diff <= $digits) {
-                    $before = ('0' x (CORE::abs($exp) - CORE::length($before) + 1)) . $before;
-                    substr($before, $exp, 0, '.');
-                }
-                else {
-                    $before .= '.';
-                    $after  .= "e$exp";
-                }
-            }
+            substr($mantissa, 0, 0, '0.' . ('0' x CORE::abs($exponent)));
         }
 
-        $str = $sgn . $before . $after;
+        $mantissa = reverse($mantissa);
+        $mantissa =~ s/^0+//;
+        $mantissa =~ s/^\.//;
+        $mantissa = reverse($mantissa);
+
+        return ($sgn . $mantissa);
     }
 
-    if (index($str, 'e') == -1) {
-        $str =~ s/0+\z//;
-        $str =~ s/\.\z//;
-    }
-
-    (!$str or $str eq '-') ? '0' : $str;
+    substr($mantissa, 1, 0, '.');
+    $sgn . $mantissa . 'e' . ($exponent - 1);
 };
 
 Class::Multimethods::multimethod __stringify__ => qw(Math::MPC) => sub {
